/*
 * Public Firebird Java API.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *    1. Redistributions of source code must retain the above copyright notice, 
 *       this list of conditions and the following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright 
 *       notice, this list of conditions and the following disclaimer in the 
 *       documentation and/or other materials provided with the distribution. 
 *    3. The name of the author may not be used to endorse or promote products 
 *       derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED 
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO 
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.firebirdsql.gds.impl;

import org.firebirdsql.gds.GDSException;
import org.firebirdsql.gds.ng.FbDatabaseFactory;
import org.firebirdsql.jaybird.props.PropertyConstants;
import org.firebirdsql.jdbc.FBSQLException;
import org.firebirdsql.util.InternalApi;

import java.sql.SQLException;

public interface GDSFactoryPlugin {

    String getPluginName();
    
    String getTypeName();
    
    String[] getTypeAliases();
    
    Class<?> getConnectionClass();
    
    String getDefaultProtocol();
    
    String[] getSupportedProtocols();

    FbDatabaseFactory getDatabaseFactory();

    String getDatabasePath(String server, Integer port, String path) throws GDSException;

    @InternalApi
    default String getDatabasePath(DbAttachInfo dbAttachInfo) throws SQLException {
        try {
            int portNumber = dbAttachInfo.getPortNumber();
            return getDatabasePath(dbAttachInfo.getServerName(),
                    portNumber != PropertyConstants.DEFAULT_PORT ? portNumber
                            : null, dbAttachInfo.getAttachObjectName());
        } catch (GDSException e) {
            throw new FBSQLException(e);
        }
    }
    
    String getDatabasePath(String jdbcUrl) throws GDSException;
}
